clc; close all; clear;
warning off;
%% Load the data
load('FreeStream_run1000.mat')
load('PressureTransducer_run1000.mat')
load('PTCalib_run1000.mat')

%% Pressure Transducer time series plot
figure;
ax1 = axes;
hold on;
N = 100; % 2/1000*fs, where fs is the samping frequency
new_start = start_ + N; % adjusting the time to capture 2ms before the flow arrives.

t_ = (t(new_start:new_start+200/1000*fs+N) - t(start_- 30))*1000;
Pinf_ = Pinf(new_start:new_start+200/1000*fs+N);

P1_ = PT(new_start:new_start+200/1000*fs+N,1); % PT1 (x = 40mm, y = 0mm)
P2_ = PT(new_start:new_start+200/1000*fs+N,2); % PT2 (x = 50mm, y = 0mm)
P3_ = PT(new_start:new_start+200/1000*fs+N,3); % PT3 (x = 60mm, y = 0mm)
P4_ = PT(new_start:new_start+200/1000*fs+N,4); % PT4 (x = 220mm, y = 0mm) Trailing edge of the cantilever plate

h1 = plot(t_,P1_,'r-');
h2 = plot(t_,P2_,'g-');
h3 = plot(t_,P3_,'b-');
h4 = plot(t_,P4_,'c-');

legend([h1, h2, h3, h4],'PT_1','PT_2','PT_3','PT_4','box', 'off','location','SouthEast','Orientation','vertical','interpreter','latex');

set(ax1,'xlim',[-10 210],'ylim',[0 1400],'ytick',[0:300:1500],...
    'box','on');
xlabel(ax1,'$t$ (ms)','fontsize',9,'units','normalized','horizontalalignment','center','verticalalignment','top','interpreter','latex');
ylabel(ax1,'$P$ (Pa)','fontsize',9,'rotation',90,'units','normalized','horizontalalignment','center','verticalalignment','bottom','interpreter','latex');

print(fig1,'-dpng','-r600','PressureTransducers.png');

%% Power Spectra plot - PTs
figure;
ax1 = axes;
hold on;

segmentlength = 2^10; % The length of the signal 
overlap = 0.5; % overlap factor
nfft = 2^16; % number of nfft points between 0 < f < fs/2; fs is the sampling frequency

[Ep1, ~] = pwelch((P1_-mean(P1_)),segmentlength,overlap*segmentlength,nfft,fs);
[Ep2, ~] = pwelch((P2_-mean(P2_)),segmentlength,overlap*segmentlength,nfft,fs);
[Ep3, ~] = pwelch((P3_-mean(P3_)),segmentlength,overlap*segmentlength,nfft,fs);
[Ep4, f] = pwelch((P4_-mean(P4_)),segmentlength,overlap*segmentlength,nfft,fs);

h1 = plot(f,f.*Ep1./trapz(f,Ep1),'r-'); 
h2 = plot(f,f.*Ep2./trapz(f,Ep2),'-','color',[0 153 0]./255);
h3 = plot(f,f.*Ep3./trapz(f,Ep3),'b-'); 
h4 = plot(f,f.*Ep4./trapz(f,Ep4),'k-');

legend([h1, h2, h3, h4],'PT_1','PT_2','PT_3','PT_4','box', 'off','location','NorthEast','Orientation','vertical','interpreter','latex');

set(ax1,'xscale','log',...
    'box','on');
xlabel(ax1,'$f$ (Hz)','fontsize',9,'units','normalized','horizontalalignment','center','verticalalignment','top','interpreter','latex')
ylabel(ax1,'PSD','fontsize',9,'rotation',90,'units','normalized','horizontalalignment','center','verticalalignment','bottom','interpreter','latex')

print(fig1,'-dpng','-r600','PSD_PressureTransducers.png');
